@@ -1,5 +1,8 @@
 package Transport::AU::PTV::Runs;
-$Transport::AU::PTV::Runs::VERSION = '0.01';
+$Transport::AU::PTV::Runs::VERSION = '0.02';
+# VERSION
+# PODNAME
+# ABSTRACT: a collection of runs on the Victorian Public Transport Network.
 
 use strict;
 use warnings;
@@ -40,11 +43,11 @@ __END__
 
 =head1 NAME
 
-Transport::AU::PTV::Runs
+Transport::AU::PTV::Runs - a collection of runs on the Victorian Public Transport Network.
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
